==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VaultKubernetesAuthBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VaultKubernetesAuthBuilder extends VaultKubernetesAuthFluentImpl<VaultKubernetesAuthBuilder> implements VisitableBuilder<VaultKubernetesAuth,VaultKubernetesAuthBuilder>{
  public VaultKubernetesAuthBuilder() {
    this(false);
  }
  public VaultKubernetesAuthBuilder(Boolean validationEnabled) {
    this(new VaultKubernetesAuth(), validationEnabled);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuthFluent<?> fluent) {
    this(fluent, false);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuthFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VaultKubernetesAuth(), validationEnabled);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuthFluent<?> fluent,VaultKubernetesAuth instance) {
    this(fluent, instance, false);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuthFluent<?> fluent,VaultKubernetesAuth instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withMountPath(instance.getMountPath());
      fluent.withRole(instance.getRole());
      fluent.withSecretRef(instance.getSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuth instance) {
    this(instance,false);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuth instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withMountPath(instance.getMountPath());
      this.withRole(instance.getRole());
      this.withSecretRef(instance.getSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  VaultKubernetesAuthFluent<?> fluent;
  Boolean validationEnabled;
  public VaultKubernetesAuth build() {
    VaultKubernetesAuth buildable = new VaultKubernetesAuth(fluent.getMountPath(),fluent.getRole(),fluent.getSecretRef());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VaultKubernetesAuthBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VaultKubernetesAuthBuilder extends VaultKubernetesAuthFluent<VaultKubernetesAuthBuilder> implements VisitableBuilder<VaultKubernetesAuth,VaultKubernetesAuthBuilder>{
  public VaultKubernetesAuthBuilder() {
    this(false);
  }
  public VaultKubernetesAuthBuilder(Boolean validationEnabled) {
    this(new VaultKubernetesAuth(), validationEnabled);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuthFluent<?> fluent) {
    this(fluent, false);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuthFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VaultKubernetesAuth(), validationEnabled);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuthFluent<?> fluent,VaultKubernetesAuth instance) {
    this(fluent, instance, false);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuthFluent<?> fluent,VaultKubernetesAuth instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new VaultKubernetesAuth());

    if (instance != null) {
      fluent.withMountPath(instance.getMountPath());
      fluent.withRole(instance.getRole());
      fluent.withSecretRef(instance.getSecretRef());
      fluent.withMountPath(instance.getMountPath());
      fluent.withRole(instance.getRole());
      fluent.withSecretRef(instance.getSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuth instance) {
    this(instance,false);
  }
  public VaultKubernetesAuthBuilder(VaultKubernetesAuth instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new VaultKubernetesAuth());

    if (instance != null) {
      this.withMountPath(instance.getMountPath());
      this.withRole(instance.getRole());
      this.withSecretRef(instance.getSecretRef());
      this.withMountPath(instance.getMountPath());
      this.withRole(instance.getRole());
      this.withSecretRef(instance.getSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  VaultKubernetesAuthFluent<?> fluent;
  Boolean validationEnabled;
  public VaultKubernetesAuth build() {
    VaultKubernetesAuth buildable = new VaultKubernetesAuth(fluent.getMountPath(),fluent.getRole(),fluent.buildSecretRef());
    return buildable;
  }
  
}
